@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,10 +22,9 @@
 
 #include <PimCommon/AbstractGenericPlugin>
 #include "kaddressbook_importexport_export.h"
-#include <QList>
-class QAction;
-namespace KAddressBookImportExport
-{
+namespace KAddressBookImportExport {
+
+/** Import/export plugin. */
 class KADDRESSBOOK_IMPORTEXPORT_EXPORT KAddressBookImportExportPlugin : public PimCommon::AbstractGenericPlugin
 {
     Q_OBJECT
